==> qt5compat-6.10.1-3.gpkg.tar: image/usr/src/debug/dev-qt/qt5compat-6.10.1/qt5compat-everywhere-src-6.10.1_build/src/imports/graphicaleffects5/private/.qt/rcc/qrc_qmake_Qt5Compat_GraphicalEffects_private.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x5d,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x51,0x74,0x35,0x43,0x6f,0x6d,0x70,0x61,0x74,0x2e,
  0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,0x73,
  0x2e,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,
  0x67,0x65,0x74,0x20,0x51,0x74,0x36,0x3a,0x3a,0x71,0x74,0x67,0x72,0x61,0x70,0x68,
  0x69,0x63,0x61,0x6c,0x65,0x66,0x66,0x65,0x63,0x74,0x73,0x70,0x72,0x69,0x76,0x61,
  0x74,0x65,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0x20,0x71,0x74,0x67,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x65,0x66,
  0x66,0x65,0x63,0x74,0x73,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x51,0x74,0x47,
  0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0x50,
  0x72,0x69,0x76,0x61,0x74,0x65,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,
  0x65,0x69,0x6e,0x66,0x6f,0x20,0x70,0x6c,0x75,0x67,0x69,0x6e,0x73,0x2e,0x71,0x6d,
  0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,
  0x71,0x74,0x2d,0x70,0x72,0x6f,0x6a,0x65,0x63,0x74,0x2e,0x6f,0x72,0x67,0x2f,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x73,0x2f,0x51,0x74,0x35,0x43,0x6f,0x6d,0x70,0x61,0x74,
  0x2f,0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,
  0x73,0x2f,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0x2f,0xa,0x44,0x72,0x6f,0x70,0x53,
  0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x20,0x36,0x2e,0x30,0x20,0x44,0x72,
  0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x2e,0x71,0x6d,0x6c,
  0xa,0x44,0x72,0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x20,
  0x31,0x2e,0x30,0x20,0x44,0x72,0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,
  0x73,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x20,
  0x36,0x2e,0x30,0x20,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,
  0xa,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x46,0x61,
  0x73,0x74,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x46,
  0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,
  0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x46,0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,
  0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,
  0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,
  0x75,0x72,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,
  0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,0x75,0x72,0x2e,0x71,
  0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,
  0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,0x75,0x72,0x20,0x31,0x2e,0x30,0x20,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,
  0x61,0x6c,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,
  0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,
  0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,
  0x73,0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x47,0x61,
  0x75,0x73,0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,
  0x72,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,
  0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,
  0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,0x72,0x20,
  0x31,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,
  0x65,0x64,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x64,0x65,0x70,0x65,0x6e,
  0x64,0x73,0x20,0x51,0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // imports
  0x0,0x7,
  0x0,0x47,0x69,0x53,
  0x0,0x69,
  0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x73,
    // Qt5Compat
  0x0,0x9,
  0x9,0xa6,0xf6,0x64,
  0x0,0x51,
  0x0,0x74,0x0,0x35,0x0,0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x61,0x0,0x74,
    // GraphicalEffects
  0x0,0x10,
  0x6,0x0,0x28,0xb3,
  0x0,0x47,
  0x0,0x72,0x0,0x61,0x0,0x70,0x0,0x68,0x0,0x69,0x0,0x63,0x0,0x61,0x0,0x6c,0x0,0x45,0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // private
  0x0,0x7,
  0x7,0x90,0xc8,0x45,
  0x0,0x70,
  0x0,0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,0x74,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects/private
  0x0,0x0,0x0,0x74,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects/private/qmldir
  0x0,0x0,0x0,0x88,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0x9c,0xf1,0xec,0x41,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qt5compat-6.10.2-1.gpkg.tar: image/usr/src/debug/dev-qt/qt5compat-6.10.2/qt5compat-everywhere-src-6.10.2_build/src/imports/graphicaleffects5/private/.qt/rcc/qrc_qmake_Qt5Compat_GraphicalEffects_private.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x5d,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x51,0x74,0x35,0x43,0x6f,0x6d,0x70,0x61,0x74,0x2e,
  0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,0x73,
  0x2e,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0xa,0x6c,0x69,0x6e,0x6b,0x74,0x61,0x72,
  0x67,0x65,0x74,0x20,0x51,0x74,0x36,0x3a,0x3a,0x71,0x74,0x67,0x72,0x61,0x70,0x68,
  0x69,0x63,0x61,0x6c,0x65,0x66,0x66,0x65,0x63,0x74,0x73,0x70,0x72,0x69,0x76,0x61,
  0x74,0x65,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0x20,0x71,0x74,0x67,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x65,0x66,
  0x66,0x65,0x63,0x74,0x73,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x51,0x74,0x47,
  0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0x50,
  0x72,0x69,0x76,0x61,0x74,0x65,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,
  0x65,0x69,0x6e,0x66,0x6f,0x20,0x70,0x6c,0x75,0x67,0x69,0x6e,0x73,0x2e,0x71,0x6d,
  0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,
  0x71,0x74,0x2d,0x70,0x72,0x6f,0x6a,0x65,0x63,0x74,0x2e,0x6f,0x72,0x67,0x2f,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x73,0x2f,0x51,0x74,0x35,0x43,0x6f,0x6d,0x70,0x61,0x74,
  0x2f,0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x61,0x6c,0x45,0x66,0x66,0x65,0x63,0x74,
  0x73,0x2f,0x70,0x72,0x69,0x76,0x61,0x74,0x65,0x2f,0xa,0x44,0x72,0x6f,0x70,0x53,
  0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x20,0x36,0x2e,0x30,0x20,0x44,0x72,
  0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x2e,0x71,0x6d,0x6c,
  0xa,0x44,0x72,0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,0x73,0x65,0x20,
  0x31,0x2e,0x30,0x20,0x44,0x72,0x6f,0x70,0x53,0x68,0x61,0x64,0x6f,0x77,0x42,0x61,
  0x73,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x20,
  0x36,0x2e,0x30,0x20,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,
  0xa,0x46,0x61,0x73,0x74,0x47,0x6c,0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x46,0x61,
  0x73,0x74,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x46,
  0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,
  0x6d,0x6c,0xa,0x46,0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x46,0x61,0x73,0x74,0x49,0x6e,0x6e,0x65,0x72,
  0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,
  0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,
  0x75,0x72,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,
  0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,0x75,0x72,0x2e,0x71,
  0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,
  0x74,0x69,0x6f,0x6e,0x61,0x6c,0x42,0x6c,0x75,0x72,0x20,0x31,0x2e,0x30,0x20,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x44,0x69,0x72,0x65,0x63,0x74,0x69,0x6f,0x6e,
  0x61,0x6c,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,0x73,0x73,
  0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,
  0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,
  0x73,0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x47,0x61,
  0x75,0x73,0x73,0x69,0x61,0x6e,0x47,0x6c,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,
  0x6f,0x77,0x20,0x31,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x49,
  0x6e,0x6e,0x65,0x72,0x53,0x68,0x61,0x64,0x6f,0x77,0x2e,0x71,0x6d,0x6c,0xa,0x47,
  0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,
  0x72,0x20,0x36,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,
  0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x47,0x61,0x75,
  0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,0x65,0x64,0x42,0x6c,0x75,0x72,0x20,
  0x31,0x2e,0x30,0x20,0x47,0x61,0x75,0x73,0x73,0x69,0x61,0x6e,0x4d,0x61,0x73,0x6b,
  0x65,0x64,0x42,0x6c,0x75,0x72,0x2e,0x71,0x6d,0x6c,0xa,0x64,0x65,0x70,0x65,0x6e,
  0x64,0x73,0x20,0x51,0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // imports
  0x0,0x7,
  0x0,0x47,0x69,0x53,
  0x0,0x69,
  0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x72,0x0,0x74,0x0,0x73,
    // Qt5Compat
  0x0,0x9,
  0x9,0xa6,0xf6,0x64,
  0x0,0x51,
  0x0,0x74,0x0,0x35,0x0,0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x61,0x0,0x74,
    // GraphicalEffects
  0x0,0x10,
  0x6,0x0,0x28,0xb3,
  0x0,0x47,
  0x0,0x72,0x0,0x61,0x0,0x70,0x0,0x68,0x0,0x69,0x0,0x63,0x0,0x61,0x0,0x6c,0x0,0x45,0x0,0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x73,
    // private
  0x0,0x7,
  0x7,0x90,0xc8,0x45,
  0x0,0x70,
  0x0,0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,0x74,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat
  0x0,0x0,0x0,0x36,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects/private
  0x0,0x0,0x0,0x74,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/imports/Qt5Compat/GraphicalEffects/private/qmldir
  0x0,0x0,0x0,0x88,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xa,0xe1,0xd0,0x35,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Qt5Compat_GraphicalEffects_private)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Qt5Compat_GraphicalEffects_private)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
